﻿init:
    #$ config.keymap['developer'].remove('D')
    $ config.keymap['console'].remove('shift_O')

    python:
    
        import math

        class Shaker(object):
        
            anchors = {
                'top' : 0.0,
                'center' : 0.5,
                'bottom' : 1.0,
                'left' : 0.0,
                'right' : 1.0,
                }
        
            def __init__(self, start, child, dist):
                if start is None:
                    start = child.get_placement()
                #
                self.start = [ self.anchors.get(i, i) for i in start ]  # central position
                self.dist = dist    # maximum distance, in pixels, from the starting point
                self.child = child
                
            def __call__(self, t, sizes):
                # Float to integer... turns floating point numbers to
                # integers.                
                def fti(x, r):
                    if x is None:
                        x = 0
                    if isinstance(x, float):
                        return int(x * r)
                    else:
                        return x

                xpos, ypos, xanchor, yanchor = [ fti(a, b) for a, b in zip(self.start, sizes) ]

                xpos = xpos - xanchor
                ypos = ypos - yanchor
                
                nx = xpos + (1.0-t) * self.dist * (renpy.random.random()*2-1)
                ny = ypos + (1.0-t) * self.dist * (renpy.random.random()*2-1)

                return (int(nx), int(ny), 0, 0)
        
        def _Shake(start, time, child=None, dist=100.0, **properties):

            move = Shaker(start, child, dist=dist)
        
            return renpy.display.layout.Motion(move,
                          time,
                          child,
                          add_sizes=True,
                          **properties)

        Shake = renpy.curry(_Shake)
init:
    $ sshake = Shake((0, 0, 0, 0), 1.0, dist=15)
    $ flash = Fade(.25, 0, .75, color="#fff")

################## Configuration Variables
define config.rollback_enabled = False  ##Disables Rollback
define config.developer = True ##Set to False to Disable Developer Menu


define config.default_sfx_volume = 0.5
define config.default_music_volume = 0.5
define config.default_text_cps = 30


image text_box_1 = ("text_box_1.png")
image text_box_2 = ("text_box_2.png")
image text_box_3 = ("text_box_3.png")


################## Backgrounds

image black = "#000000"
image white = "#ffffff"
image castle = "bg/SD_BGCastle.png"
image mist = "bg/SD_BGCastleMist.png"
image castle_hall = "bg/SD_BGHall.png"
image date_table = "bg/SD_BGSpeedDate.png"
image Dungeon = "bg/SD_BGBlob.png"
image Bookstore = "bg/SD_BGInvis.png"
image Garden = "bg/SD_BGMedusa.png"
image Trees = "bg/SD_BGSassy.png"
image Theater = "bg/SD_BGVamp.png"
image Cabin = "bg/SD_BGWerewolf.png"
image Graveyard = "bg/SD_BGZombie.png"

################## Characters

##Beholder

define bhface = 'mad'

image Beholder = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "bh_face",
    )
)

image bh_face = ConditionSwitch(
    "bhface == 'neutral'", "misc/BeholderN.png",
    "bhface == 'happy'", "misc/BeholderHappy.png",
    "bhface == 'mad'", "misc/BeholderMad.png"
)

################## Werewolf

define wwclothes = 'empty'
define wwface = 'neutral'
define wwbody = '1'

image Werewolf = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "ww_body",
    (0,0), "ww_clothes",
    (0,0), "ww_face",
    )
)

image ww_body = ConditionSwitch(
    "wwbody == '1'", "ww/WWBody01.png",
    "wwbody == '2'", "ww/WWBody02.png",
)

image ww_face = ConditionSwitch(
    "wwface == 'neutral'", "ww/WWFaceN.png",
    "wwface == 'happy'", "ww/WWFaceHap.png",
    "wwface == 'mad'", "ww/WWFaceMad.png",
    "wwface == 'death'", "ww/WWFaceDeath.png"
)

image ww_clothes = ConditionSwitch(
    "wwclothes == 'empty'", "ww/empty.png",
    "wwclothes == '1'", "ww/WWOutfit01.png",
    "wwclothes == '2'", "ww/WWOutfit02.png",
    "wwclothes == '3'", "ww/WWOutfit03.png"
)


################## Zombie

define zombody = '1'
define zomclothes = 'empty'
define zomface = 'neutral'
define zomflower = 'empty'
define zomjaw = 'jaw'

image Zombie = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "zom_body",
    (0,0), "zom_clothes",
    (0,0), "zom_flower",
    (0,0), "zom_face",
    (0,0), "zom_jaw",
    )
)

image zom_body = ConditionSwitch(
    "zombody == '1'", "zom/ZomBody01.png",
    "zombody == '2'", "zom/ZomBody02.png",
)

image zom_jaw = ConditionSwitch(
    "zomjaw == 'empty'", "ww/empty.png",
    "zomjaw == 'jaw'", "zom/ZombieJaw.png",
)


image zom_face = ConditionSwitch(
    "zomface == 'neutral'", "zom/ZomFaceN.png",
    "zomface == 'happy'", "zom/ZomHappy.png",
    "zomface == 'mad'", "zom/ZomMad.png",
    "zomface == 'death'", "zom/ZomFaceDeath.png"
)

image zom_clothes = ConditionSwitch(
    "zomclothes == 'empty'", "ww/empty.png",
    "zomclothes == '1'", "zom/ZomOutfit01.png",
    "zomclothes == '2'", "zom/ZomOutfit02.png",
    "zomclothes == '3'", "zom/ZomOutfit03.png"
)

image zom_flower = ConditionSwitch(
    "zomflower == 'empty'", "ww/empty.png",
    "zomflower == '1'", "zom/ZomFlower.png",
)


################## Vampire

define vampbody = '1'
define vampclothes = 'empty'
define vampface = 'neutral'

image Vampire = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "vamp_body",
    (0,0), "vamp_clothes",
    (0,0), "vamp_face",
    )
)

image vamp_body = ConditionSwitch(
    "vampbody == '1'", "vamp/VampBody01.png",
    "vampbody == '2'", "vamp/VampBody02.png",
)

image vamp_face = ConditionSwitch(
    "vampface == 'neutral'", "vamp/VampFaceN.png",
    "vampface == 'happy'", "vamp/VampFaceHappy.png",
    "vampface == 'mad'", "vamp/VampFaceMad.png",
    "vampface == 'death'", "vamp/VampFaceDeath.png"
)

image vamp_clothes = ConditionSwitch(
    "vampclothes == 'empty'", "ww/empty.png",
    "vampclothes == '1'", "vamp/VampOutfit01.png",
    "vampclothes == '2'", "vamp/VampOutfit02.png",
    "vampclothes == '3'", "vamp/VampOutfit03.png",
)

################## Medusa

define medbody = '1'
define medclothes = 'empty'
define medface = 'neutral'

image Medusa = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "med_body",
    (0,0), "med_face",
    (0,0), "med_clothes",
    )
)

image med_body = ConditionSwitch(
    "medbody == '1'", "med/MedusaBody01.png",
    "medbody == '2'", "med/MedusaBody02.png",
)

image med_face = ConditionSwitch(
    "medface == 'neutral'", "med/MedusaFaceN.png",
    "medface == 'happy'", "med/MedusaFaceHappy.png",
    "medface == 'mad'", "med/MedusaFaceMad.png",
    "medface == 'death'", "med/MedusaFaceDeath.png"
)

image med_clothes = ConditionSwitch(
    "medclothes == 'empty'", "ww/empty.png",
    "medclothes == '1'", "med/MedusaOutfit01.png",
    "medclothes == '2'", "med/MedusaOutfit02.png",
    "medclothes == '3'", "med/MedusaOutfit03.png",
)

################## Sasquatch

define sasbody = '1'
define sasclothes = 'empty'
define sasface = 'happy'

image Sasquatch = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "sas_body",
    (0,0), "sas_clothes",
    (0,0), "sas_face",
    )
)

image sas_body = ConditionSwitch(
    "sasbody == '1'", "sas/SassyBody01.png",
    "sasbody == '2'", "sas/SassyBody02.png",
)

image sas_face = ConditionSwitch(
    "sasface == 'neutral'", "sas/SassyFaceN.png",
    "sasface == 'happy'", "sas/SassyFaceHappy.png",
    "sasface == 'alt'", "sas/SassyFaceAlt.png",
    "sasface == 'death'", "sas/SassyFaceDeath.png"
)

image sas_clothes = ConditionSwitch(
    "sasclothes == 'empty'", "ww/empty.png",
    "sasclothes == '1'", "sas/SassyOutfit01.png",
    "sasclothes == '2'", "sas/SassyOutfit02.png",
    "sasclothes == '3'", "sas/SassyOutfit03.png",
)

################## Invisible

define invface = 'neutral'

image Invisible = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "inv_face",
    )
)

image inv_face = ConditionSwitch(
    "invface == 'neutral'", "inv/InvisFaceN.png",
    "invface == 'happy'", "inv/InvisFaceHappy.png",
    "invface == 'mad'", "inv/InvisFaceMad.png",
    "invface == 'strangle'", "inv/InvisFaceDeath.png"
)


################## Blob

define blobbody = '1'
define blobclothes = 'empty'
define blobface = 'neutral'

image Blob = Flatten(LiveComposite(
    (1280, 720),
    (0,0), "blob_clothes",
    (0,0), "blob_face",
    )
)


image blob_face = ConditionSwitch(
    "blobface == 'neutral'", "blob/SlimeFaceN.png",
    "blobface == 'happy'", "blob/SlimeFaceHappy.png",
    "blobface == 'mad'", "blob/SlimeFaceMad.png",
    "blobface == 'neutral2'", "blob/SlimeBody02N.png",
    "blobface == 'happy2'", "blob/SlimeBody02Happy.png",
    "blobface == 'mad2'", "blob/SlimeBody02Mad.png",
    "blobface == 'death'", "blob/BlobFaceDeath.png"
)

image blob_clothes = ConditionSwitch(
    "blobclothes == '0'", "blob/SlimeOutfit03.png",
    "blobclothes == '1'", "blob/SlimeOutfit01.png",
    "blobclothes == '2'", "blob/SlimeOutfit02.png",
)


################## Death

image Death = "images/Death.png"

################## Characters and Speakers dialog  

define beho = Character(None, window_background = ("text_box_1"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define ww = Character(None, window_background = ("text_box_2"), what_xpos=0.715, what_ypos=0.11, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define zom = Character(None, window_background = ("text_box_blob"), what_xpos=0.225, what_ypos=0.24, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define vamp = Character(None, window_background = ("text_box_1"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define med = Character(None, window_background = ("text_box_med"), what_xpos=0.663, what_ypos=0.11, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define blob = Character(None, window_background = ("text_box_blob"), what_xpos=0.225, what_ypos=0.24, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define inv = Character(None, window_background = ("text_box_1"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define sas = Character(None, window_background = ("text_box_1"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")
define d = Character(None, window_background = ("text_box_1"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720, ctc="ctc_blink")

define nar = Character(None, window_background = ("text_box_3"), what_xpos=0.14, what_ypos=0.16, what_color = "#000000",  what_xsize  = 220, what_ysize  = 720)

define narrator = Character(ctc="ctc_blink")

##Active and Passed date
define dating_who = '' 
define dated_werewolf = False
define dated_sasquatch = False
define dated_vampire = False
define dated_blob = False
define dated_medusa = False
define dated_invisible = False
define dated_zombie = False

##Determines of a Question has been asked alraedy
define q1 = False
define q2 = False
define q3 = False
define q4 = False
define q5 = False
define q6 = False

define q7 = False
define q8 = False
define q9 = False
define q10 = False
define q11 = False
define q12 = False

define q13 = False
define q14 = False
define q15 = False
define q16 = False
define q17 = False
define q18 = False

##For choosing which random questions are asked
define generic_question1 = 0
define generic_question2 = 0

##RATE YOUR DATE VAR

define q1_1 = False
define q1_2 = False
define q1_3 = False
define q1_4 = False
define q1_5 = False

define q2_1 = False
define q2_2 = False
define q2_3 = False
define q2_4 = False
define q2_5 = False

define q3_1 = False
define q3_2 = False
define q3_3 = False
define q3_4 = False
define q3_5 = False

define q4_1 = False
define q4_2 = False
define q4_3 = False
define q4_4 = False
define q4_5 = False

define q5_1 = False
define q5_2 = False
define q5_3 = False
define q5_4 = False
define q5_5 = False

define q1_score = 0
define q2_score = 0
define q3_score = 0
define q4_score = 0
define q5_score = 0

define total_score = 0

define ww_total_score = 0
define med_total_score = 0
define inv_total_score = 0
define blob_total_score = 0
define sas_total_score = 0
define vamp_total_score = 0
define zom_total_score = 0

##DEATHS

define persistent.ww_death = False
define persistent.sas_death = False
define persistent.inv_death = False
define persistent.zom_death = False
define persistent.med_death = False
define persistent.vamp_death = False
define persistent.blob_death = False

##Played

define persistent.played = False
define persistent.murdered = 0
define persistent.chose_death = False
define persistent.refused_death = False


##Chooses Random Date
# $ random_date = renpy.random.choice(['werewolf', 'bigfoot', 'vampire'])

    
define winner = ''
    
# The game starts here.
$ player_scores = { "Werewolf" : 0, "Invisible": 0, "Vampire": 0, "Blob": 0, "Medusa": 0, "Sasquatch": 0, "Zombie": 0,}
$ total_score = 0
$ ww_total_score = 0
$ med_total_score = 0
$ inv_total_score = 0
$ blob_total_score = 0
$ sas_total_score = 0
$ vamp_total_score = 0
$ zom_total_score = 0

## Transforms


transform hovering:
    linear 0.5 ypos 1.01
    linear 0.5 ypos 0.99
    repeat
    on hide:
        linear 0.5 alpha 0


label start:


##Start Scene OUtside view of a large castle on a black backdrop.  Lightning flashes from time to time.  Dark broody music
##MC talks about their plot of killing the monsters and how the lair is found.
##Greeted by an igor butler thing and escorted through the castle.
## Door opens and the music changes to something corny, and you're suddenly at the table.
##Igor gives you a question sheet and talks about the rules.  Game starts with random date.
    
    $ player_scores = { "Werewolf" : 0, "Invisible": 0, "Vampire": 0, "Blob": 0, "Medusa": 0, "Sasquatch": 0, "Zombie": 0,}
    
    $_game_menu_screen = "preferences"
    
    if persistent.chose_death == True:
        scene black with dissolve
        "There is nothing left for you in the castle."
        "You have perished, and all of the inhabitants are gone."
        "If only there was a way to do it all over again..."
        "Oh wait, there is!"
        "Would you like to reset all that you did?"
        menu:
            "Yes (Warning! This cannot be undone.)":
                $ persistent.ww_death = False
                $ persistent.sas_death = False
                $ persistent.inv_death = False
                $ persistent.zom_death = False
                $ persistent.med_death = False
                $ persistent.vamp_death = False
                $ persistent.blob_death = False
                $ persistent.played = False
                $ persistent.murdered = 0
                $ persistent.chose_death = False
                $ persistent.refused_death = False
                "It is done!"
                return
            "No":
                "So be it."
                return
                
    if persistent.refused_death == True:
        stop music
        $music("Gloom")
        scene castle 
        show mist
        with dissolve
        play sound "sound/thunder_2.ogg"
        "Death said to return if you reconsidered the offer."
        "It would still be waiting."
        scene date_table with dissolve
        $ music("Empty")
        show Death with dissolve
        d "I wondered when you would return."
        d "Have you reconsidered?"
        d "Will you accept my offer?"
        menu:
            "Yes":
                $ persistent.chose_death = True
                d "Excellent."
                d "A verbal contract is all I need."
                d "You will work for me from now on!"
                d "Your task for eternity will be to hunt down the souls that have escaped their afterlife."
                d "Now, I ask you politely to {b}DIE{/b}."
                play sound "sound/decapitate.wav"
                scene white with flash
                "Death's offer was too good of a deal to pass up."
                "To hunt those unworthy of life for all eternity was like a dream come true."
                "Your death was quick and painless, but in that moment..."
                "All of the lives you had stolen away flashed by your eyes."
                "Every moment of fear."
                "Every moment of pain."
                "Every moment of suffering."
                "You experienced it all in an instant."
                "From that point on, every soul you captured while in Death's employ."
                "You got to experience it all over again."
                scene black with dissolve
                jump end_screen
            "No":
                d "Then why did you come back and waste my time?"
                d "Be gone."
                hide Death with dissolve
                scene black with dissolve
                "You left the castle, but the call of Death was still there."
                "Should you return, the offer would be waiting..."
                return
    
    
    stop music
    $music("Gloom")
    if persistent.ww_death == True and persistent.sas_death == True and persistent.inv_death == True and persistent.zom_death == True and persistent.med_death == True and persistent.vamp_death == True and persistent.blob_death == True:
        scene castle
        show mist
        with dissolve
    else:
        scene castle
    play sound "sound/thunder_2.ogg"
    
    if persistent.played == True:
        "A new disguise, and you were able to just waltz right back in."
        "None of them would be the wiser to what was going on..."
    else:
        "For years, you've hunted monsters from all across the lands."
        "To you, they were a plague upon the land, and you swore your life to eradicating them."
        "This time around, they practically invited you right in!"
        "Little did they know that they would all soon meet their end."
    if persistent.ww_death == True and persistent.sas_death == True and persistent.inv_death == True and persistent.zom_death == True and persistent.med_death == True and persistent.vamp_death == True and persistent.blob_death == True:
        jump special_date
    scene castle_hall with dissolve
    show Beholder with dissolve
    show Beholder at hovering
    beho "So you've arrived.  Right this way then."
    beho "All of our other guests have arrived, so the festivities will begin soon."
    hide Beholder with dissolve
    $music("Comic")
    scene date_table with dissolve#with flash of white
    $ bhface = 'happy'
    show Beholder with dissolve
    show Beholder at hovering
    beho "Thank you for joining us tonight on this special occasion!"
    beho "Welcome to our speed dating monster bash!  I'm your host, Beauty!"
    $ bhface = 'neutral'
    beho "Tonight, you'll be meeting our roster of singles for a fun night of looking for love."
    beho "Will you leave with someone's number?  Or will you leave without?"
    $ bhface = 'happy'
    beho "We'll find out soon enough!"
    $ bhface = 'neutral'
    beho "You have only a few minutes with each of our ready-to-mingle singles, so probe their minds to see if you're a match!"
    if persistent.murdered >= 5:   
        beho "Though, our turnout has been less and less here lately..."
        beho "Anyway!"
    beho "Once you hear the bell chime, you'll be introduced to a new bachelor or bachelorette to chat with."
    beho "In case you need some help getting started, here's a cheat-sheet of questions you can ask your could-be lover."
    $ bhface = 'happy'
    beho "Good luck and haaaaave fun!"
    hide Beholder with dissolve
    #if persistent.played == False:   
     #   nar "Perfect.  I can gather information about them and then take them out later."
    #else:
        #nar "I have a lot of information already, but even more couldn't hurt."
    play sound "sound/time_up.ogg"
    $ renpy.pause(delay=2, hard=True)
    jump pick_random_date

label end_screen:
    $ persistent.played = True
    $ persistent.murdered += 1
    "End~"
    return
    
label reset:
    $ persistent.ww_death = False
    $ persistent.sas_death = False
    $ persistent.inv_death = False
    $ persistent.zom_death = False
    $ persistent.med_death = False
    $ persistent.vamp_death = False
    $ persistent.blob_death = False
    $ persistent.played = False
    $ persistent.murdered = 0
    $ persistent.chose_death = False
    $ persistent.refused_death = False
    $ renpy.full_restart()